@@ -136,6 +136,7 @@ second character.
     \g<name>        Matches the text matched by the group named name.
     \G              Matches the empty string, but only at the position where
                     the search started.
+    \h              Matches horizontal whitespace.
     \K              Keeps only what follows for the entire match.
     \L<name>        Named list. The list is provided as a keyword argument.
     \m              Matches the empty string, but only at the start of a word.
@@ -231,62 +232,63 @@ This module also defines an exception 'error'.
 """
 
 # Public symbols.
-__all__ = ["compile", "escape", "findall", "finditer", "fullmatch", "match",
-  "purge", "search", "split", "splititer", "sub", "subf", "subfn", "subn",
-  "template", "Scanner", "A", "ASCII", "B", "BESTMATCH", "D", "DEBUG", "E",
-  "ENHANCEMATCH", "S", "DOTALL", "F", "FULLCASE", "I", "IGNORECASE", "L",
-  "LOCALE", "M", "MULTILINE", "P", "POSIX", "R", "REVERSE", "T", "TEMPLATE",
-  "U", "UNICODE", "V0", "VERSION0", "V1", "VERSION1", "X", "VERBOSE", "W",
-  "WORD", "error", "Regex"]
+__all__ = ["cache_all", "compile", "DEFAULT_VERSION", "escape", "findall",
+  "finditer", "fullmatch", "match", "purge", "search", "split", "splititer",
+  "sub", "subf", "subfn", "subn", "template", "Scanner", "A", "ASCII", "B",
+  "BESTMATCH", "D", "DEBUG", "E", "ENHANCEMATCH", "S", "DOTALL", "F",
+  "FULLCASE", "I", "IGNORECASE", "L", "LOCALE", "M", "MULTILINE", "P", "POSIX",
+  "R", "REVERSE", "T", "TEMPLATE", "U", "UNICODE", "V0", "VERSION0", "V1",
+  "VERSION1", "X", "VERBOSE", "W", "WORD", "error", "Regex", "__version__",
+  "__doc__"]
 
-__version__ = "2.5.3"
+__version__ = "2.5.91"
 
 # --------------------------------------------------------------------
 # Public interface.
 
 def match(pattern, string, flags=0, pos=None, endpos=None, partial=False,
-  concurrent=None, **kwargs):
+  concurrent=None, ignore_unused=False, **kwargs):
     """Try to apply the pattern at the start of the string, returning a match
     object, or None if no match was found."""
-    return _compile(pattern, flags, kwargs).match(string, pos, endpos,
-      concurrent, partial)
+    pat = _compile(pattern, flags, ignore_unused, kwargs, True)
+    return pat.match(string, pos, endpos, concurrent, partial)
 
 def fullmatch(pattern, string, flags=0, pos=None, endpos=None, partial=False,
-  concurrent=None, **kwargs):
+  concurrent=None, ignore_unused=False, **kwargs):
     """Try to apply the pattern against all of the string, returning a match
     object, or None if no match was found."""
-    return _compile(pattern, flags, kwargs).fullmatch(string, pos, endpos,
-      concurrent, partial)
+    pat = _compile(pattern, flags, ignore_unused, kwargs, True)
+    return pat.fullmatch(string, pos, endpos, concurrent, partial)
 
 def search(pattern, string, flags=0, pos=None, endpos=None, partial=False,
-  concurrent=None, **kwargs):
+  concurrent=None, ignore_unused=False, **kwargs):
     """Search through string looking for a match to the pattern, returning a
     match object, or None if no match was found."""
-    return _compile(pattern, flags, kwargs).search(string, pos, endpos,
-      concurrent, partial)
+    pat = _compile(pattern, flags, ignore_unused, kwargs, True)
+    return pat.search(string, pos, endpos, concurrent, partial)
 
 def sub(pattern, repl, string, count=0, flags=0, pos=None, endpos=None,
-  concurrent=None, **kwargs):
+  concurrent=None, ignore_unused=False, **kwargs):
     """Return the string obtained by replacing the leftmost (or rightmost with a
     reverse pattern) non-overlapping occurrences of the pattern in string by the
     replacement repl. repl can be either a string or a callable; if a string,
     backslash escapes in it are processed; if a callable, it's passed the match
     object and must return a replacement string to be used."""
-    return _compile(pattern, flags, kwargs).sub(repl, string, count, pos,
-      endpos, concurrent)
+    pat = _compile(pattern, flags, ignore_unused, kwargs, True)
+    return pat.sub(repl, string, count, pos, endpos, concurrent)
 
 def subf(pattern, format, string, count=0, flags=0, pos=None, endpos=None,
-  concurrent=None, **kwargs):
+  concurrent=None, ignore_unused=False, **kwargs):
     """Return the string obtained by replacing the leftmost (or rightmost with a
     reverse pattern) non-overlapping occurrences of the pattern in string by the
     replacement format. format can be either a string or a callable; if a string,
     it's treated as a format string; if a callable, it's passed the match object
     and must return a replacement string to be used."""
-    return _compile(pattern, flags, kwargs).subf(format, string, count, pos,
-      endpos, concurrent)
+    pat = _compile(pattern, flags, ignore_unused, kwargs, True)
+    return pat.subf(format, string, count, pos, endpos, concurrent)
 
 def subn(pattern, repl, string, count=0, flags=0, pos=None, endpos=None,
-  concurrent=None, **kwargs):
+  concurrent=None, ignore_unused=False, **kwargs):
     """Return a 2-tuple containing (new_string, number). new_string is the string
     obtained by replacing the leftmost (or rightmost with a reverse pattern)
     non-overlapping occurrences of the pattern in the source string by the
@@ -294,11 +296,11 @@ def subn(pattern, repl, string, count=0, flags=0, pos=None, endpos=None,
     can be either a string or a callable; if a string, backslash escapes in it
     are processed; if a callable, it's passed the match object and must return a
     replacement string to be used."""
-    return _compile(pattern, flags, kwargs).subn(repl, string, count, pos,
-      endpos, concurrent)
+    pat = _compile(pattern, flags, ignore_unused, kwargs, True)
+    return pat.subn(repl, string, count, pos, endpos, concurrent)
 
 def subfn(pattern, format, string, count=0, flags=0, pos=None, endpos=None,
-  concurrent=None, **kwargs):
+  concurrent=None, ignore_unused=False, **kwargs):
     """Return a 2-tuple containing (new_string, number). new_string is the string
     obtained by replacing the leftmost (or rightmost with a reverse pattern)
     non-overlapping occurrences of the pattern in the source string by the
@@ -306,52 +308,68 @@ def subfn(pattern, format, string, count=0, flags=0, pos=None, endpos=None,
     can be either a string or a callable; if a string, it's treated as a format
     string; if a callable, it's passed the match object and must return a
     replacement string to be used."""
-    return _compile(pattern, flags, kwargs).subfn(format, string, count, pos,
-      endpos, concurrent)
+    pat = _compile(pattern, flags, ignore_unused, kwargs, True)
+    return pat.subfn(format, string, count, pos, endpos, concurrent)
 
-def split(pattern, string, maxsplit=0, flags=0, concurrent=None, **kwargs):
+def split(pattern, string, maxsplit=0, flags=0, concurrent=None,
+  ignore_unused=False, **kwargs):
     """Split the source string by the occurrences of the pattern, returning a
     list containing the resulting substrings.  If capturing parentheses are used
     in pattern, then the text of all groups in the pattern are also returned as
     part of the resulting list.  If maxsplit is nonzero, at most maxsplit splits
     occur, and the remainder of the string is returned as the final element of
     the list."""
-    return _compile(pattern, flags, kwargs).split(string, maxsplit, concurrent)
+    pat = _compile(pattern, flags, ignore_unused, kwargs, True)
+    return pat.split(string, maxsplit, concurrent)
 
-def splititer(pattern, string, maxsplit=0, flags=0, concurrent=None, **kwargs):
+def splititer(pattern, string, maxsplit=0, flags=0, concurrent=None,
+  ignore_unused=False, **kwargs):
     "Return an iterator yielding the parts of a split string."
-    return _compile(pattern, flags, kwargs).splititer(string, maxsplit,
-      concurrent)
+    pat = _compile(pattern, flags, ignore_unused, kwargs, True)
+    return pat.splititer(string, maxsplit, concurrent)
 
 def findall(pattern, string, flags=0, pos=None, endpos=None, overlapped=False,
-  concurrent=None, **kwargs):
+  concurrent=None, ignore_unused=False, **kwargs):
     """Return a list of all matches in the string. The matches may be overlapped
     if overlapped is True. If one or more groups are present in the pattern,
     return a list of groups; this will be a list of tuples if the pattern has
     more than one group. Empty matches are included in the result."""
-    return _compile(pattern, flags, kwargs).findall(string, pos, endpos,
-      overlapped, concurrent)
+    pat = _compile(pattern, flags, ignore_unused, kwargs, True)
+    return pat.findall(string, pos, endpos, overlapped, concurrent)
 
 def finditer(pattern, string, flags=0, pos=None, endpos=None, overlapped=False,
-  partial=False, concurrent=None, **kwargs):
+  partial=False, concurrent=None, ignore_unused=False, **kwargs):
     """Return an iterator over all matches in the string. The matches may be
     overlapped if overlapped is True. For each match, the iterator returns a
     match object. Empty matches are included in the result."""
-    return _compile(pattern, flags, kwargs).finditer(string, pos, endpos,
-      overlapped, concurrent, partial)
+    pat = _compile(pattern, flags, ignore_unused, kwargs, True)
+    return pat.finditer(string, pos, endpos, overlapped, concurrent, partial)
 
-def compile(pattern, flags=0, **kwargs):
+def compile(pattern, flags=0, ignore_unused=False, **kwargs):
     "Compile a regular expression pattern, returning a pattern object."
-    return _compile(pattern, flags, kwargs)
+    return _compile(pattern, flags, ignore_unused, kwargs, _cache_all)
 
 def purge():
     "Clear the regular expression cache"
     _cache.clear()
     _locale_sensitive.clear()
 
+# Whether to cache all patterns.
+_cache_all = True
+
+def cache_all(value=True):
+    """Sets whether to cache all patterns, even those are compiled explicitly.
+    Passing None has no effect, but returns the current setting."""
+    global _cache_all
+
+    if value is None:
+        return _cache_all
+
+    _cache_all = value
+
 def template(pattern, flags=0):
     "Compile a template pattern, returning a pattern object."
-    return _compile(pattern, flags | TEMPLATE)
+    return _compile(pattern, flags | TEMPLATE, False, {}, False)
 
 def escape(pattern, special_only=True, literal_spaces=False):
     """Escape a string for use as a literal in a pattern. If special_only is
@@ -395,8 +413,8 @@ from _regex_core import (_ALL_VERSIONS, _ALL_ENCODINGS, _FirstSetError,
   _UnscopedFlagSet, _check_group_features, _compile_firstset,
   _compile_replacement, _flatten_code, _fold_case, _get_required_string,
   _parse_pattern, _shrink_cache)
-from _regex_core import (ALNUM as _ALNUM, Info as _Info, OP as _OP, Source as
-  _Source, Fuzzy as _Fuzzy)
+from _regex_core import (ALNUM as _ALNUM, Info as _Info, OP as _OP, Source
+  as _Source, Fuzzy as _Fuzzy)
 
 # Version 0 is the old behaviour, compatible with the original 're' module.
 # Version 1 is the new behaviour, which differs slightly.
@@ -418,11 +436,18 @@ _locale_sensitive = {}
 _MAXCACHE = 500
 _MAXREPCACHE = 500
 
-def _compile(pattern, flags=0, kwargs={}):
+def _compile(pattern, flags, ignore_unused, kwargs, cache_it):
     "Compiles a regular expression to a PatternObject."
 
+    global DEFAULT_VERSION
+    try:
+        from regex import DEFAULT_VERSION
+    except ImportError:
+        pass
+
     # We won't bother to cache the pattern if we're debugging.
-    debugging = (flags & DEBUG) != 0
+    if (flags & DEBUG) != 0:
+        cache_it = False
 
     # What locale is this pattern using?
     locale_key = (type(pattern), pattern)
@@ -433,7 +458,7 @@ def _compile(pattern, flags=0, kwargs={}):
         # This pattern is definitely not locale-sensitive.
         pattern_locale = None
 
-    if not debugging:
+    if cache_it:
         try:
             # Do we know what keyword arguments are needed?
             args_key = pattern, type(pattern), flags
@@ -555,6 +580,12 @@ def _compile(pattern, flags=0, kwargs={}):
         named_list_indexes[index] = items
         args_needed.add((name, values))
 
+    # Any unused keyword arguments, possibly resulting from a typo?
+    unused_kwargs = set(kwargs) - set(named_lists)
+    if unused_kwargs and not ignore_unused:
+        any_one = next(iter(unused_kwargs))
+        raise ValueError('unused keyword argument %r' % any_one)
+
     # Check the features of the groups.
     _check_group_features(info, parsed)
 
@@ -606,7 +637,7 @@ def _compile(pattern, flags=0, kwargs={}):
         finally:
             _cache_lock.release()
 
-    if not debugging:
+    if cache_it:
         if (info.flags & LOCALE) == 0:
             pattern_locale = None
 
@@ -675,8 +706,10 @@ def _compile_replacement_helper(pattern, template):
     return compiled
 
 # We define Pattern here after all the support objects have been defined.
-Pattern = type(_compile('', 0, {}))
-Match = type(_compile('', 0).match(''))
+_pat = _compile('', 0, False, {}, False)
+Pattern = type(_pat)
+Match = type(_pat.match(''))
+del _pat
 
 # We'll define an alias for the 'compile' function so that the repr of a
 # pattern object is eval-able.
